
.. _config-reference:

=============================
Configuration reference
=============================


The configuration file is in `toml format <https://github.com/toml-lang/toml>`__. See :ref:`config-intro` for examples and discussion. Below is the config file specification.


.. marshmallow:: mario.declarative:CommandSpecSchema
